@@ -1,12 +1,13 @@
 /* vi: set sw=4 ts=4:
  *
- * Copyright (C) 2001 - 2007 Christian Hohnstaedt.
+ * Copyright (C) 2001 - 2010 Christian Hohnstaedt.
  *
  * All rights reserved.
  */
 
 
 #include "asn1int.h"
+#include "func.h"
 #include "exception.h"
 #include <openssl/err.h>
 #include <openssl/bn.h>
@@ -91,22 +92,14 @@ QString a1int::toDec() const
 	return r;
 }
 
-void a1int::openssl_error()  const
-{
-	QString errtxt;
-	QString error = "asn1 Integer error:";
-	while (int i = ERR_get_error() ) {
-	   errtxt = ERR_error_string(i ,NULL);
-	   error += errtxt + "\n";
-	}
-	throw errorEx(error, "a1int");
-}
-
 a1int &a1int::setHex(const QString &s)
 {
 	BIGNUM *bn=0;
+	if (s.isEmpty()) {
+		return *this;
+	}
 	if (!BN_hex2bn(&bn,s.toAscii()))
-	  openssl_error();
+		openssl_error();
 	BN_to_ASN1_INTEGER(bn, in);
 	BN_free(bn);
 	return *this;
@@ -116,7 +109,7 @@ a1int &a1int::setDec(const QString &s)
 {
 	BIGNUM *bn=0;
 	if (!BN_dec2bn(&bn,s.toAscii()))
-	  openssl_error();
+		openssl_error();
 	BN_to_ASN1_INTEGER(bn, in);
 	BN_free(bn);
 	return *this;
@@ -124,8 +117,9 @@ a1int &a1int::setDec(const QString &s)
 
 a1int &a1int::setRaw(const unsigned char *data, unsigned len)
 {
-	BIGNUM *bn=BN_bin2bn(data,len,NULL);
-	if (!bn) openssl_error();
+	BIGNUM *bn = BN_bin2bn(data, len, NULL);
+	if (!bn)
+		openssl_error();
 	BN_to_ASN1_INTEGER(bn, in);
 	BN_free(bn);
 	return *this;
