@@ -1,14 +1,14 @@
 /* vi: set sw=4 ts=4:
  *
- * Copyright (C) 2001 - 2007 Christian Hohnstaedt.
+ * Copyright (C) 2001 - 2010 Christian Hohnstaedt.
  *
  * All rights reserved.
  */
 
-#ifndef ASN1INTEGER_H
-#define ASN1INTEGER_H
+#ifndef __ASN1INTEGER_H
+#define __ASN1INTEGER_H
 
-#include <qstring.h>
+#include <QtCore/QString>
 #include <openssl/asn1.h>
 
 class a1int
@@ -16,7 +16,6 @@ class a1int
    private:
 	ASN1_INTEGER *in;
 	ASN1_INTEGER *dup(const ASN1_INTEGER *a) const;
-	void openssl_error()  const;
    public:
 	a1int();
 	a1int(const ASN1_INTEGER *i);
