@@ -1,6 +1,6 @@
 /* vi: set sw=4 ts=4:
  *
- * Copyright (C) 2001 - 2010 Christian Hohnstaedt.
+ * Copyright (C) 2001 - 2012 Christian Hohnstaedt.
  *
  * All rights reserved.
  */
@@ -157,7 +157,7 @@ int db::next(int flag)
 		return -1;
 	}
 	if (!verify_magic()){
-		printf("Garbage found at %lu\n", head_offset);
+		printf("Garbage found at %lu\n", (unsigned long)head_offset);
 		head_offset+=4;
 		return next(flag);
 	}
@@ -199,6 +199,7 @@ QString db::uniq_name(QString s, QList<enum pki_type> types)
 	QStringList sl;
 	bool ok;
 
+	s = s.left(NAMELEN-6);
 	sl = s.split("_");
 	sl.last().toUInt(&ok, 10);
 	if (ok && (sl.count() > 1)) {
