@@ -5,22 +5,21 @@
  * All rights reserved.
  */
 
-#ifndef DB_CRL_H
-#define DB_CRL_H
+#ifndef __DB_CRL_H
+#define __DB_CRL_H
 
 #include "db_x509.h"
 #include "pki_crl.h"
-#include "widgets/ExportDer.h"
-#include <qobject.h>
-#include <qpixmap.h>
-#include <qevent.h>
+#include "widgets/ExportDialog.h"
+#include <QtCore/QObject>
+#include <QtGui/QPixmap>
+#include <QtGui/QContextMenuEvent>
 
-class db_crl: public db_base
+class db_crl: public db_x509name
 {
 		Q_OBJECT
 	protected:
 		QPixmap *crlicon;
-		db_x509 *certs;
 	public:
 		db_crl(QString db, MainWindow *mw);
 		pki_base *newPKI(db_header_t *head = NULL);
