@@ -1,6 +1,6 @@
 /* vi: set sw=4 ts=4:
  *
- * Copyright (C) 2001 - 2007 Christian Hohnstaedt.
+ * Copyright (C) 2001 - 2010 Christian Hohnstaedt.
  *
  * All rights reserved.
  */
@@ -8,8 +8,9 @@
 #include "db.h"
 #include "exception.h"
 #include <stdlib.h>
+#include <qbytearray.h>
 
-const char *QString2filename(const QString &fname)
+QByteArray filename2bytearray(const QString &fname)
 {
 #ifdef WIN32
 	return fname.toLocal8Bit();
