@@ -1,17 +1,17 @@
 /* vi: set sw=4 ts=4:
  *
- * Copyright (C) 2001 - 2007 Christian Hohnstaedt.
+ * Copyright (C) 2001 - 2010 Christian Hohnstaedt.
  *
  * All rights reserved.
  */
 
-#ifndef DB_KEY_H
-#define DB_KEY_H
+#ifndef __DB_KEY_H
+#define __DB_KEY_H
 
 #include "db_base.h"
 #include "pki_key.h"
-#include <qstringlist.h>
-#include <qobject.h>
+#include <QtCore/QStringList>
+#include <QtCore/QObject>
 
 class MainWindow;
 class QModelIndex;
@@ -25,7 +25,7 @@ class db_key: public db_base
 	public:
 		db_key(QString db, MainWindow *mw);
 		QStringList getPrivateDesc();
-		QStringList get0PrivateDesc(bool all = false);
+		QStringList get0KeyDesc(bool all = false);
 		pki_base *newPKI(db_header_t *head = NULL);
 		void inToCont(pki_base *pki);
 		void remFromCont(QModelIndex &idx);
@@ -44,6 +44,7 @@ class db_key: public db_base
 		void changePin();
 		void initPin();
 		void changeSoPin();
+		void toToken();
 
 	signals:
 		void delKey(pki_key *delkey);
