@@ -1,6 +1,6 @@
 /* vi: set sw=4 ts=4:
  *
- * Copyright (C) 2001 - 2007 Christian Hohnstaedt.
+ * Copyright (C) 2001 - 2010 Christian Hohnstaedt.
  *
  * All rights reserved.
  */
@@ -10,21 +10,19 @@
 #include "func.h"
 #include <widgets/NewX509.h>
 #include <widgets/MainWindow.h>
-#include <qfiledialog.h>
-#include <qdir.h>
-#include <qevent.h>
-#include <qaction.h>
-#include <qinputdialog.h>
-#include <qmessagebox.h>
+#include <QtGui/QFileDialog>
+#include <QtCore/QDir>
+#include <QtGui/QContextMenuEvent>
+#include <QtGui/QAction>
+#include <QtGui/QInputDialog>
+#include <QtGui/QMessageBox>
 
 db_temp::db_temp(QString DBfile, MainWindow *mw)
-	:db_base(DBfile, mw)
+	:db_x509name(DBfile, mw)
 {
-	headertext << "Name" << "Type";
-	delete_txt = tr("Delete the template(s)");
-	view = mw->tempView;
+	allHeaders << new dbheader(HD_temp_type, true, tr("Type"));
 	class_name = "templates";
-	pkitype[0] = tmpl;
+	pkitype << tmpl;
 
 	loadContainer();
 
@@ -48,7 +46,7 @@ db_temp::db_temp(QString DBfile, MainWindow *mw)
 				predefs->append(tmpl);
 		} catch(errorEx &err) {
 			QMessageBox::warning(mainwin, tr(XCA_TITLE),
-				tr("Bad template: ") + name);
+				tr("Bad template: %1").arg(name));
 		}
 	}
 }
@@ -58,7 +56,7 @@ db_temp::~db_temp()
 	delete predefs;
 }
 
-pki_base *db_temp::newPKI(db_header_t *head)
+pki_base *db_temp::newPKI(db_header_t *)
 {
 	return new pki_temp("");
 }
@@ -135,6 +133,7 @@ void db_temp::newItem()
 		temp->setIntName("--");
 		if (runTempDlg(temp)) {
 			insertPKI(temp);
+			createSuccess(temp);
 			return;
 		}
 	}
@@ -242,8 +241,7 @@ void db_temp::showContextMenu(QContextMenuEvent *e, const QModelIndex &index)
 				SLOT(certFromTemp()));
 		menu->addAction(tr("Create request"), this, SLOT(reqFromTemp()));
 	}
-	menu->exec(e->globalPos());
-	delete menu;
+	contextMenu(e, menu);
 	currentIdx = QModelIndex();
 	return;
 }
