@@ -6,17 +6,18 @@
  */
 
 
-#ifndef DB_TEMP_H
-#define DB_TEMP_H
+#ifndef __DB_TEMP_H
+#define __DB_TEMP_H
 
 #include "db_base.h"
 #include "pki_temp.h"
-#include <qobject.h>
-#include <qpixmap.h>
+#include "db_x509super.h"
+#include <QtCore/QObject>
+#include <QtGui/QPixmap>
 
 class Mainwin;
 
-class db_temp: public db_base
+class db_temp: public db_x509name
 {
 	Q_OBJECT
     protected:
