@@ -1,17 +1,17 @@
 /* vi: set sw=4 ts=4:
  *
- * Copyright (C) 2001 - 2007 Christian Hohnstaedt.
+ * Copyright (C) 2001 - 2010 Christian Hohnstaedt.
  *
  * All rights reserved.
  */
 
 
-#ifndef DB_X509_H
-#define DB_X509_H
+#ifndef __DB_X509_H
+#define __DB_X509_H
 
-#include <qlistview.h>
-#include <qobject.h>
-#include <qpixmap.h>
+#include <QtGui/QListView>
+#include <QtCore/QObject>
+#include <QtGui/QPixmap>
 #include "db_key.h"
 #include "db_x509super.h"
 #include "pki_x509.h"
@@ -51,6 +51,8 @@ class db_x509: public db_x509super
 		void showContextMenu(QContextMenuEvent *e, const QModelIndex &index);
 		void inToCont(pki_base *pki);
 		void changeView();
+		a1int getUniqueSerial(pki_x509 *signer);
+		void myToToken(bool alwaysSelect);
 
 	public slots:
 		void load(void);
@@ -60,13 +62,15 @@ class db_x509: public db_x509super
 		void showPki(pki_base *pki);
 		void setMultiTrust(QAbstractItemView* view);
 		void setTrust();
+		void deleteFromToken();
 		void extendCert();
 		void revoke();
 		void unRevoke();
 		void genCrl();
 		void caProperties();
 		void toRequest();
-		void toScard();
+		void toToken();
+		void toOtherToken();
 		void newCert(pki_temp *);
 		void newCert(pki_x509req *);
 		void loadPKCS12();
