@@ -1,6 +1,6 @@
 /* vi: set sw=4 ts=4:
  *
- * Copyright (C) 2001 - 2010 Christian Hohnstaedt.
+ * Copyright (C) 2001 - 2012 Christian Hohnstaedt.
  *
  * All rights reserved.
  */
@@ -53,7 +53,7 @@ class errorEx
 #define check_oom(ptr) \
 	if(!ptr) { \
 		throw errorEx(QObject::tr("Out of Memory at %1:%2").\
-			arg(__FILE__).arg(__LINE__)); \
+			arg(C_FILE).arg(__LINE__)); \
 	}
 
 #endif
