@@ -6,10 +6,10 @@
  */
 
 
-#ifndef LOAD_OBJ_H
-#define LOAD_OBJ_H
+#ifndef __LOAD_OBJ_H
+#define __LOAD_OBJ_H
 
-#include <qstringlist.h>
+#include <QtCore/QStringList>
 
 class pki_base;
 
