@@ -1,6 +1,6 @@
 /* vi: set sw=4 ts=4:
  *
- * Copyright (C) 2001 - 2010 Christian Hohnstaedt.
+ * Copyright (C) 2001 - 2012 Christian Hohnstaedt.
  *
  * All rights reserved.
  */
@@ -17,8 +17,8 @@
 #include "headerlist.h"
 
 #define __ME QString("(%1:%2)").arg(class_name).arg(getIntName())
-#define pki_openssl_error() _openssl_error(__ME, __FILE__, __LINE__)
-#define pki_ign_openssl_error() _ign_openssl_error(__ME, __FILE__, __LINE__)
+#define pki_openssl_error() _openssl_error(__ME, C_FILE, __LINE__)
+#define pki_ign_openssl_error() _ign_openssl_error(__ME, C_FILE, __LINE__)
 
 class pki_base : public QObject
 {
@@ -102,6 +102,10 @@ class pki_base : public QObject
 			return NULL;
 		}
 		void fwrite_ba(FILE *fp, QByteArray ba, QString fname);
+		virtual QVariant bg_color(dbheader *hd)
+		{
+			return QVariant();
+		}
 };
 
 #endif
