@@ -1,6 +1,6 @@
 /* vi: set sw=4 ts=4:
  *
- * Copyright (C) 2001 - 2010 Christian Hohnstaedt.
+ * Copyright (C) 2001 - 2012 Christian Hohnstaedt.
  *
  * All rights reserved.
  */
@@ -18,6 +18,7 @@
 #include <QtCore/QDir>
 #include <openssl/rand.h>
 
+bool pki_x509::dont_colorize_expiries = false;
 QPixmap *pki_x509::icon[6] = { NULL, NULL, NULL, NULL, NULL, NULL };
 
 pki_x509::pki_x509(X509 *c)
@@ -131,11 +132,11 @@ void pki_x509::init()
 	psigner = NULL;
 	trust = 0;
 	efftrust = 0;
-	revoked.now();
+	revoked = a1time::now();
 	caSerial = 1;
 	caTemplate = "";
 	crlDays = 30;
-	crlExpiry.now();
+	crlExpiry = a1time::now();
 	class_name = "pki_x509";
 	cert = NULL;
 	isrevoked = false;
@@ -378,12 +379,14 @@ bool pki_x509::verifyQASerial(const a1int &secret) const
 
 void pki_x509::setNotBefore(const a1time &a)
 {
-	a.set_date(&X509_get_notBefore(cert));
+	a1time t(a);
+	X509_set_notBefore(cert, t.get_utc());
 }
 
 void pki_x509::setNotAfter(const a1time &a)
 {
-	a.set_date(&X509_get_notAfter(cert));
+	a1time t(a);
+	X509_set_notAfter(cert, t.get_utc());
 }
 
 a1time pki_x509::getNotBefore() const
@@ -632,14 +635,22 @@ QString pki_x509::fingerprint(const EVP_MD *digest)
 	return fp;
 }
 
-int pki_x509::checkDate()
+bool pki_x509::checkDate()
 {
-	a1time a; a.now();
-	int ret = 0;
-	if (getNotAfter() <  a) ret = -1;
-	if (getNotBefore() > a) ret = 1;
+	a1time n, b, a;
+
+	n = a1time::now(),
+	b = getNotBefore();
+	a = getNotAfter();
+
+	if (!a.isValid() || !b.isValid())
+		return false;
+	if (!a.isUndefined() && (a < n))
+		return false;
+	if (b > n)
+		return false;
 	pki_openssl_error();
-	return ret;
+	return true;
 }
 
 extList pki_x509::getV3ext()
@@ -699,7 +710,7 @@ void pki_x509::setRevoked(bool rev, a1time inval, QString reason)
 {
 	if (rev) {
 		setEffTrust(0);
-		revoked.now();
+		revoked = a1time::now();
 		pki_openssl_error();
 		revoke_reason = reason;
 		invalDate = inval;
@@ -866,6 +877,54 @@ const EVP_MD *pki_x509::getDigest()
 	return EVP_get_digestbyobj(cert->sig_alg->algorithm);
 }
 
+QVariant pki_x509::bg_color(dbheader *hd)
+{
+#define BG_RED     QBrush(QColor(255,  0,  0))
+#define BG_YELLOW  QBrush(QColor(255,255,  0))
+#define BG_CYAN    QBrush(QColor(127,255,212))
+
+	if (dont_colorize_expiries)
+		return QVariant();
+
+	a1time nb, na, now, certwarn;
+
+	nb = getNotBefore();
+	na = getNotAfter();
+	now = a1time::now();
+
+	int lifetime = nb.secsTo(na);
+
+	/* warn after 4/5 certificate lifetime */
+	certwarn = na.addSecs(- lifetime /5);
+
+	switch (hd->id) {
+		case HD_cert_notBefore:
+			if (nb > now || !nb.isValid() || nb.isUndefined())
+				return QVariant(BG_RED);
+			break;
+		case HD_cert_notAfter: {
+			if (na.isUndefined())
+				return QVariant(BG_CYAN);
+			if (na < now)
+				return QVariant(BG_RED);
+			if (certwarn < now)
+				return QVariant(BG_YELLOW);
+			break;
+		}
+		case HD_cert_revokation:
+			if (canSign()) {
+				QDateTime crlwarn, crlex;
+				crlex = crlExpiry;
+				crlwarn = crlex.addSecs(-2 *60*60*24);
+				if (crlex < now)
+					return QVariant(BG_RED);
+				if (crlwarn < now || !crlex.isValid())
+					return QVariant(BG_YELLOW);
+			}
+	}
+	return QVariant();
+}
+
 void pki_x509::oldFromData(unsigned char *p, int size)
 {
 	int version, sRev, sLastCrl;
@@ -883,14 +942,14 @@ void pki_x509::oldFromData(unsigned char *p, int size)
 			revoked.d2i(ba);
 		}
 		else {
-		   isrevoked = false;
-		   revoked.now();
+			isrevoked = false;
+			revoked = a1time::now();
 		}
 
 		if (version == 1) {
 			caTemplate="";
 			caSerial=1;
-			crlExpiry.now();
+			crlExpiry=a1time::now();
 			crlDays=30;
 		}
 
