@@ -1,12 +1,12 @@
 /* vi: set sw=4 ts=4:
  *
- * Copyright (C) 2001 - 2009 Christian Hohnstaedt.
+ * Copyright (C) 2001 - 2011 Christian Hohnstaedt.
  *
  * All rights reserved.
  */
 
-#ifndef PKI_X509REQ_H
-#define PKI_X509REQ_H
+#ifndef __PKI_X509REQ_H
+#define __PKI_X509REQ_H
 
 #include <openssl/x509.h>
 #include <openssl/pem.h>
@@ -20,9 +20,10 @@ class pki_x509;
 
 class pki_x509req : public pki_x509super
 {
+		Q_OBJECT
 	private:
 		//loading spkac file and convert it to a request
-		void load_spkac(const QString filename);
+		int load_spkac(const QString filename);
 		//for checking spkac content-fields
 		int fix_data(int nid, int *type);
 
@@ -41,12 +42,14 @@ class pki_x509req : public pki_x509super
 		~pki_x509req();
 		void fromData(const unsigned char *p, db_header_t *head);
 		void oldFromData(unsigned char *p, int size);
-		unsigned char *toData(int *size);
-		bool compare(pki_base *refreq);
+		QByteArray toData();
 		x509name getSubject() const;
 		bool isSpki() const;
 		void writeReq(const QString fname, bool pem);
-		X509_REQ *getReq() {return request;}
+		X509_REQ *getReq()
+		{
+			return request;
+		}
 		void addAttribute(int nid, QString content);
 
 		int verify();
@@ -56,13 +59,23 @@ class pki_x509req : public pki_x509super
 		QString getSigAlg();
 		void setSubject(const x509name &n);
 		/* SPKAC special functions */
-		void setSPKIBase64(const char *p);
-		void set_spki(NETSCAPE_SPKI *_spki);
 		ASN1_IA5STRING *spki_challange();
-		QVariant column_data(int col);
-		QVariant getIcon(int column);
-		void setDone() { done = true; }
-		bool getDone() { return done; }
+		QVariant column_data(dbheader *hd);
+		QVariant getIcon(dbheader *hd);
+		void setDone(bool d = true)
+		{
+			done = d;
+		}
+		bool getDone()
+		{
+			return done;
+		}
+		virtual QString getMsg(msg_type msg);
+		void d2i(QByteArray &ba);
+		void d2i_spki(QByteArray &ba);
+		QByteArray i2d();
+		QByteArray i2d_spki();
+		BIO *pem(BIO *);
 };
 
 #endif
