@@ -1,10 +1,11 @@
 /* vi: set sw=4 ts=4:
  *
- * Copyright (C) 2001 - 2009 Christian Hohnstaedt.
+ * Copyright (C) 2001 - 2010 Christian Hohnstaedt.
  *
  * All rights reserved.
  */
 
+#include <QtGui/QMessageBox>
 #include "x509name.h"
 #include "base.h"
 #include "func.h"
@@ -22,6 +23,17 @@ x509name::x509name(const X509_NAME *n)
 	xn = X509_NAME_dup((X509_NAME *)n);
 }
 
+x509name::x509name(STACK_OF(X509_NAME_ENTRY) *entries)
+{
+	X509_NAME *n = X509_NAME_new();
+	STACK_OF(X509_NAME_ENTRY) *ba = n->entries;
+	xn = NULL;
+	n->entries = entries;
+	set(n);
+	n->entries = ba;
+	X509_NAME_free(n);
+}
+
 x509name::x509name(const x509name &n)
 {
 	xn = NULL;
@@ -41,7 +53,6 @@ x509name &x509name::set(const X509_NAME *n)
 	return *this;
 }
 
-
 QString x509name::oneLine(unsigned long flags) const
 {
 	QString ret;
@@ -116,6 +127,11 @@ QString x509name::popEntryByNid(int nid)
 	return n;
 }
 
+QString x509name::hash() const
+{
+	return QString("%1").arg(X509_NAME_hash(xn), 8, 16, QChar('0'));
+}
+
 QStringList x509name::entryList(int i) const
 {
 	QStringList sl;
@@ -143,31 +159,25 @@ int x509name::nid(int i) const
 QString x509name::getOid(int i) const
 {
 	X509_NAME_ENTRY *ne;
-	char buf[256];
-	int len;
 
 	ne = sk_X509_NAME_ENTRY_value(xn->entries, i);
 	if (ne == NULL)
 		return QString();
-	len = OBJ_obj2txt(buf, 256, ne->object, 1);
-	return QString::fromAscii(buf, len);
+	return OBJ_obj2QString(ne->object, 1);
 }
 
-const unsigned char *x509name::d2i(const unsigned char *p, int size)
+void x509name::d2i(QByteArray &ba)
 {
-	X509_NAME *xn_sik = xn;
-	xn = D2I_CLASH(d2i_X509_NAME, NULL, &p, size);
-	if (xn == NULL)
-		xn = xn_sik;
-	else
-		X509_NAME_free(xn_sik);
-	return p;
+	X509_NAME *n = (X509_NAME*)d2i_bytearray(D2I_VOID(d2i_X509_NAME), ba);
+	if (n) {
+		X509_NAME_free(xn);
+		xn = n;
+	}
 }
 
-unsigned char *x509name::i2d(unsigned char *p)
+QByteArray x509name::i2d()
 {
-	i2d_X509_NAME(xn, &p);
-	return p;
+	 return i2d_bytearray(I2D_VOID(i2d_X509_NAME), xn);
 }
 
 bool x509name::operator == (const x509name &x) const
@@ -191,23 +201,55 @@ int x509name::getNidByName(const QString &nid_name)
 	return OBJ_txt2nid(nid_name.toAscii());
 }
 
+QString x509name::checkLength() const
+{
+	ASN1_STRING_TABLE *tab;
+	int i, max = entryCount();
+	QString warn;
+
+	for (i=0; i<max; i++) {
+		int n = nid(i);
+		QString entry;
+
+		tab = ASN1_STRING_TABLE_get(n);
+		if (!tab)
+			continue;
+		entry = getEntry(i);
+		if (tab->minsize > entry.size()) {
+			warn += QObject::tr("%1 is shorter than %2 bytes: '%3'").
+				arg(OBJ_nid2ln(n)).arg(tab->maxsize).arg(entry);
+			warn += "\n";
+		}
+		if ((tab->maxsize != -1) && (tab->maxsize < entry.size())) {
+			warn += QObject::tr("%1 is longer than %2 bytes: '%3'").
+				arg(OBJ_nid2ln(n)).arg(tab->maxsize).arg(entry);
+			warn += "\n";
+		}
+	}
+	return warn;
+}
+
+QString x509name::taggedValues() const
+{
+	int i, max = entryCount();
+	QString ret;
+
+	for (i=0; i<max; i++) {
+		int n = nid(i);
+		ret += QString("%1.%2=%3\n").
+			arg(i).arg(OBJ_nid2sn(n)).arg(getEntry(i));
+	}
+	return ret;
+}
+
 void x509name::addEntryByNid(int nid, const QString entry)
 {
 	if (entry.isEmpty())
 		return;
 	ASN1_STRING *a = QStringToAsn1(entry, nid);
-	if (!a) {
-		QString error = QString(OBJ_nid2ln(nid)) + ":\n";
-		while (int i = ERR_get_error() ) {
-			fprintf(stderr, "OpenSSL error: %s\n", ERR_error_string(i ,NULL) );
-			error += ERR_error_string(i, NULL);
-			error += "\n";
-		}
-		throw errorEx(error, "x509name");
-		return;
-	}
 	X509_NAME_add_entry_by_NID(xn, nid, a->type, a->data, a->length, -1, 0);
 	ASN1_STRING_free(a);
+	openssl_error(QString("'%1' (%2)").arg(entry).arg(OBJ_nid2ln(nid)));
 }
 
 X509_NAME *x509name::get() const
@@ -215,7 +257,3 @@ X509_NAME *x509name::get() const
 	return X509_NAME_dup(xn);
 }
 
-int x509name::derSize() const
-{
-	return i2d_X509_NAME(xn, NULL);
-}
