@@ -1,15 +1,15 @@
 /* vi: set sw=4 ts=4:
  *
- * Copyright (C) 2001 - 2009 Christian Hohnstaedt.
+ * Copyright (C) 2001 - 2010 Christian Hohnstaedt.
  *
  * All rights reserved.
  */
 
-#ifndef X509NAME_H
-#define X509NAME_H
+#ifndef __X509NAME_H
+#define __X509NAME_H
 
-#include <qstring.h>
-#include <qstringlist.h>
+#include <QtCore/QString>
+#include <QtCore/QStringList>
 #include <openssl/x509.h>
 
 class x509name
@@ -20,13 +20,14 @@ class x509name
 		x509name();
 		x509name(const X509_NAME *n);
 		x509name(const x509name &n);
+		x509name(STACK_OF(X509_NAME_ENTRY) *entries);
 		~x509name();
 		x509name &set(const X509_NAME *n);
 		QString oneLine(unsigned long flags = XN_FLAG_ONELINE) const;
 		int nid(int i) const;
 		QString getOid(int i) const;
-		const unsigned char *d2i(const unsigned char *p, int size);
-		unsigned char *i2d(unsigned char *p);
+		QByteArray i2d();
+		void d2i(QByteArray &ba);
 		QStringList entryList(int i) const;
 		QString getEntryByNid(int nid ) const;
 		QString getEntry(int i) const;
@@ -36,11 +37,12 @@ class x509name
 		bool operator == (const x509name &x) const;
 		static int getNidByName(const QString &nid_name);
 		void addEntryByNid(int nid, const QString entry);
+		QString checkLength() const;
 		QString popEntryByNid(int nid);
 		X509_NAME *get() const;
-		int derSize() const;
 		QString getMostPopular() const;
-
+		QString taggedValues() const;
+		QString hash() const;
 };
 
 #endif
