@@ -1,6 +1,6 @@
 /* vi: set sw=4 ts=4:
  *
- * Copyright (C) 2001 - 2007 Christian Hohnstaedt.
+ * Copyright (C) 2001 - 2010 Christian Hohnstaedt.
  *
  * All rights reserved.
  */
@@ -9,8 +9,9 @@
 #define __IMPORTMULTI_H
 
 #include "ui_ImportMulti.h"
+#include "lib/db_token.h"
 #include "lib/db_base.h"
-#include <qlist.h>
+#include <QtCore/QList>
 
 class pki_x509;
 class pki_key;
@@ -20,22 +21,30 @@ class ImportMulti: public QDialog, private Ui::ImportMulti
 	Q_OBJECT
 
 	private:
-		db_base *mcont;
+		slotid slot;
+		db_token *mcont;
 		MainWindow *mainwin;
+		void importError(QStringList failed);
+
 	public:
 		ImportMulti(MainWindow *parent);
 		~ImportMulti();
 		void addItem(pki_base *pki);
 		pki_base *getSelected();
-		void import(QModelIndex &idx);
-		void execute(int force=0);
+		pki_base *import(QModelIndex &idx);
+		void execute(int force=0, QStringList failed = QStringList());
 		int entries();
+		void tokenInfo(slotid s);
+		void dragEnterEvent(QDragEnterEvent *event);
+		void dropEvent(QDropEvent *event);
 
 	public slots:
 		void on_butRemove_clicked();
 		void on_butImport_clicked();
 		void on_butDetails_clicked();
 		void on_butOk_clicked();
+		void on_deleteToken_clicked();
+		void on_renameToken_clicked();
 
 };
 
