@@ -1,6 +1,6 @@
 /* vi: set sw=4 ts=4:
  *
- * Copyright (C) 2001 - 2009 Christian Hohnstaedt.
+ * Copyright (C) 2001 - 2010 Christian Hohnstaedt.
  *
  * All rights reserved.
  */
@@ -12,9 +12,9 @@
 #include "lib/pki_scard.h"
 #include "widgets/distname.h"
 #include "widgets/clicklabel.h"
-#include <qlabel.h>
-#include <qpushbutton.h>
-#include <qlineedit.h>
+#include <QtGui/QLabel>
+#include <QtGui/QPushButton>
+#include <QtGui/QLineEdit>
 
 KeyDetail::KeyDetail(QWidget *parent)
 	:QDialog(parent)
@@ -25,6 +25,7 @@ KeyDetail::KeyDetail(QWidget *parent)
 	keyDesc->setReadOnly(true);
 }
 
+#ifndef OPENSSL_NO_EC
 static QString CurveComment(int nid)
 {
 	for (size_t i=0; i<pki_evp::num_curves; i++) {
@@ -33,31 +34,29 @@ static QString CurveComment(int nid)
 	}
 	return QString();
 }
+#endif
 
 void KeyDetail::setKey(pki_key *key)
 {
-	int nid;
-	QString title = tr("Details of the ") +key->getTypeString() +tr(" key");
-
 	keyDesc->setText(key->getIntName());
 	keyLength->setText(key->length());
 
 	keyPrivEx->disableToolTip();
-	if (!key->isScard())
+	if (!key->isToken())
 		cardBox->hide();
-	tlHeader->setText(tr("Details of the") + " " + key->getTypeString() +
-		" " + tr(" key"));
+	tlHeader->setText(tr("Details of the %1 key").arg(key->getTypeString()));
 
 	if (key->isPubKey()) {
 		keyPrivEx->setText(tr("Not available"));
 		keyPrivEx->setRed();
-	} else if (key->isScard()) {
+	} else if (key->isToken()) {
 		image->setPixmap(*MainWindow::scardImg);
 		pki_scard *card = (pki_scard *)key;
-		cardBox->setTitle(tr("Card") +" [" +card->getCardLabel() +"]");
-		cardManufacturer->setText(card->getManufacturer());
+		cardBox->setTitle(tr("Token") +" [" +card->getCardLabel() +"]");
+		cardManufacturer->setText(card->getManufacturer() + " " +
+					card->getModel());
 		cardSerial->setText(card->getSerial());
-		keyPrivEx->setText(tr("Smart card ID: ") +card->getId());
+		keyPrivEx->setText(tr("Security token ID:%1").arg(card->getId()));
 		keyBox->setTitle(tr("Key") + " [" + card->getLabel() + "]");
 	} else {
 		keyPrivEx->setText(tr("Available"));
@@ -75,7 +74,9 @@ void KeyDetail::setKey(pki_key *key)
 			keyPubEx->setText(key->subprime());
 			keyModulus->setText(key->pubkey());
 			break;
+#ifndef OPENSSL_NO_EC
 		case EVP_PKEY_EC:
+			int nid;
 			nid = key->ecParamNid();
 			tlModulus->setText(tr("Public key"));
 			tlPrivEx->setText(tr("Private key"));
@@ -84,7 +85,8 @@ void KeyDetail::setKey(pki_key *key)
 			keyPubEx->setToolTip(CurveComment(nid));
 			keyModulus->setText(key->ecPubKey());
 			break;
+#endif
 		default:
-			tlHeader->setText(tr("UNKNOWN Key"));
+			tlHeader->setText(tr("Unknown key"));
 	}
 }
