@@ -1,6 +1,6 @@
 /* vi: set sw=4 ts=4:
  *
- * Copyright (C) 2001 - 2010 Christian Hohnstaedt.
+ * Copyright (C) 2001 - 2012 Christian Hohnstaedt.
  *
  * All rights reserved.
  */
@@ -47,7 +47,7 @@ int MainWindow::init_database()
 	hashBox::resetDefault();
 	pkcs11path = getDefaultPkcs11Lib();
 	workingdir = QDir::currentPath();
-	pki_base::suppress_messages = 0;
+	setOptFlags((QString()));
 	try {
 		pkcs11_lib p(pkcs11path);
 	} catch (errorEx &e) {
@@ -138,6 +138,13 @@ int MainWindow::init_database()
 					pki_base::suppress_messages = 1;
 			}
 		}
+		mydb.first();
+		if (!mydb.find(setting, "optionflags")) {
+			if ((p = (char *)mydb.load(NULL))) {
+				setOptFlags((QString(p)));
+				free(p);
+			}
+		}
 		ASN1_STRING_set_default_mask_asc((char*)CCHAR(string_opt));
 		mydb.first();
 		if (!mydb.find(setting, "mw_geometry")) {
@@ -163,7 +170,7 @@ int MainWindow::init_database()
 	}
 	setWindowTitle(tr(XCA_TITLE));
 	setItemEnabled(true);
-	if (pki_evp::passwd.isEmpty())
+	if (pki_evp::passwd.isNull())
 		QMessageBox::information(this, XCA_TITLE,
 			tr("Using or exporting private keys will not be possible without providing the correct password"));
 
@@ -317,6 +324,7 @@ void MainWindow::close_database()
 	keys = NULL;
 
 	pki_evp::passwd.cleanse();
+	pki_evp::passwd = QByteArray();
 
 	if (!crls)
 		return;
