@@ -1,6 +1,6 @@
 /* vi: set sw=4 ts=4:
  *
- * Copyright (C) 2001 - 2010 Christian Hohnstaedt.
+ * Copyright (C) 2001 - 2012 Christian Hohnstaedt.
  *
  * All rights reserved.
  */
@@ -41,7 +41,7 @@ QPixmap *MainWindow::keyImg = NULL, *MainWindow::csrImg = NULL,
 	*MainWindow::certImg = NULL, *MainWindow::tempImg = NULL,
 	*MainWindow::nsImg = NULL, *MainWindow::revImg = NULL,
 	*MainWindow::appIco = NULL, *MainWindow::scardImg = NULL,
-	*MainWindow::doneIco = NULL;
+	*MainWindow::doneIco = NULL, *MainWindow::warnIco = NULL;
 
 db_key *MainWindow::keys = NULL;
 db_x509req *MainWindow::reqs = NULL;
@@ -217,6 +217,7 @@ void MainWindow::dropEvent(QDropEvent *event)
 	}
 	dlgi->execute(1, failed);
 	delete dlgi;
+	event->acceptProposedAction();
 }
 
 void MainWindow::dragEnterEvent(QDragEnterEvent *event)
@@ -270,6 +271,7 @@ void MainWindow::init_images()
 	scardImg = loadImg("bigscard.png");
 	appIco = loadImg("key.xpm");
 	doneIco = loadImg("done.png");
+	warnIco = loadImg("warn.png");
 	bigKey->setPixmap(*keyImg);
 	bigCsr->setPixmap(*csrImg);
 	bigCert->setPixmap(*certImg);
@@ -751,8 +753,10 @@ int MainWindow::initPass()
 			p.setDescription(tr("Please enter the password for unlocking the database:\n%1").arg(compressFilename(dbfile)));
 			ret = PwDialog::execute(&p, &pki_evp::passwd,
 						false, true);
-			if (ret != 1)
+			if (ret != 1) {
+				pki_evp::passwd = QByteArray();
 				return ret;
+			}
 			if (pki_evp::passHash.left(1) == "S")
 				continue;
 			/* Start automatic update from md5 to salted sha512
@@ -771,6 +775,8 @@ int MainWindow::initPass()
 			}
 		}
 	}
+	if (pki_evp::passwd.isNull())
+		pki_evp::passwd = "";
 	return 1;
 }
 
