@@ -1,6 +1,6 @@
 /* vi: set sw=4 ts=4:
  *
- * Copyright (C) 2001 - 2010 Christian Hohnstaedt.
+ * Copyright (C) 2001 - 2012 Christian Hohnstaedt.
  *
  * All rights reserved.
  */
@@ -48,6 +48,8 @@ class MainWindow: public QMainWindow, public Ui::MainWindow
 		QLabel *statusLabel;
 		QString homedir;
 		int changeDB(QString fname);
+		void setOptFlags(QString flags);
+		QString getOptFlags();
 
 	public:
 		static db_x509 *certs;
@@ -57,7 +59,7 @@ class MainWindow: public QMainWindow, public Ui::MainWindow
 		static db_crl *crls;
 		static QPixmap *keyImg, *csrImg, *certImg, *tempImg,
 				*nsImg, *revImg, *appIco, *scardImg,
-				*doneIco;
+				*doneIco, *warnIco;
 		static NIDlist *eku_nid, *dn_nid, *aia_nid;
 		static QString mandatory_dn;
 		int exitApp;
