@@ -1,6 +1,6 @@
 /* vi: set sw=4 ts=4:
  *
- * Copyright (C) 2001 - 2009 Christian Hohnstaedt.
+ * Copyright (C) 2001 - 2010 Christian Hohnstaedt.
  *
  * All rights reserved.
  */
@@ -9,6 +9,8 @@
 #define __NEWKEY_H
 
 #include "ui_NewKey.h"
+#include "lib/pkcs11_lib.h"
+#include <QtCore/QStringList>
 
 class NewKey: public QDialog, public Ui::NewKey
 {
@@ -19,6 +21,8 @@ class NewKey: public QDialog, public Ui::NewKey
 		int getKeytype();
 		int getKeysize();
 		int getKeyCurve_nid();
+		slotid getKeyCardSlot();
+		bool isToken();
 	public slots:
 		void on_keyType_currentIndexChanged(int);
 
