@@ -1,20 +1,22 @@
 /* vi: set sw=4 ts=4:
  *
- * Copyright (C) 2001 - 2009 Christian Hohnstaedt.
+ * Copyright (C) 2001 - 2012 Christian Hohnstaedt.
  *
  * All rights reserved.
  */
 
 
 #include "NewX509.h"
-#include <qcheckbox.h>
-#include <qcombobox.h>
-#include <qradiobutton.h>
-#include <qlineedit.h>
-#include <qlistwidget.h>
-#include <qmessagebox.h>
+#include <QtGui/QCheckBox>
+#include <QtGui/QComboBox>
+#include <QtGui/QRadioButton>
+#include <QtGui/QLineEdit>
+#include <QtGui/QListWidget>
+#include <QtGui/QMessageBox>
+
 #include "MainWindow.h"
 #include "lib/x509v3ext.h"
+#include "lib/func.h"
 
 
 x509v3ext NewX509::getBasicConstraints()
@@ -26,7 +28,9 @@ x509v3ext NewX509::getBasicConstraints()
 		if (bcCritical->isChecked())
 			cont << "critical";
 		cont << ca[basicCA->currentIndex()];
-		if (!basicPath->text().isEmpty()) {
+		if (basicCA->currentIndex() == 1 &&
+		   !basicPath->text().isEmpty())
+		{
 			cont << QString("pathlen:") +
 				QString::number(basicPath->text().toInt());
 		}
@@ -47,14 +51,16 @@ x509v3ext NewX509::getSubKeyIdent()
 x509v3ext NewX509::getAuthKeyIdent()
 {
 	x509v3ext ext;
-	if (authKey->isChecked() && authKey->isEnabled()) {
-		if (foreignSignRB->isChecked())
-			ext.create(NID_authority_key_identifier,
-				"keyid,issuer:always", &ext_ctx);
-		else
-			ext.create(NID_authority_key_identifier,
-				"keyid,issuer", &ext_ctx);
+	if (!authKey->isChecked() || !authKey->isEnabled())
+		return ext;
+
+	QString x = "keyid,issuer:always";
+	if (ext_ctx.issuer_cert && X509_get_ext_by_NID(ext_ctx.issuer_cert,
+				NID_subject_key_identifier, -1) != -1)
+	{
+		x = "keyid:always,issuer:always";
 	}
+	ext.create(NID_authority_key_identifier, x, &ext_ctx);
 	return ext;
 }
 
@@ -91,7 +97,7 @@ x509v3ext NewX509::getEkeyUsage()
 		//QListWidgetItem *li = ekeyUsage->item(i);
 		//printf("rows = %d, ekeyUsage = %d, %p\n", rows, i, li);
 		if (ekeyUsage->isItemSelected(ekeyUsage->item(i))) {
-			cont << (QString)OBJ_nid2sn(eku_nid[i]);
+			cont << QString(OBJ_nid2sn(eku_nid[i]));
 		}
 	}
 	if (ekuCritical->isChecked() && cont.count() > 0)
@@ -151,27 +157,26 @@ QString NewX509::getAuthInfAcc_string()
 		rval = OBJ_nid2sn(aia_nid[aiaOid->currentIndex()]);
 		rval += ";" + aia_txt;
 	}
+	openssl_error();
 	return rval;
 }
 
 void NewX509::setAuthInfAcc_string(QString aia_txt)
 {
-	QStringList aia;
-	int nid;
+	int nid, idx;
 
-	aia = aia_txt.split(';');
-
-	if (aia.count() != 2)
+	idx = aia_txt.indexOf(';');
+	if (idx == -1)
 		return;
 
-	nid = OBJ_sn2nid(CCHAR(aia[0]));
+	nid = OBJ_txt2nid(CCHAR(aia_txt.left(idx)));
 
 	for (int i=0; i < aia_nid.count(); i++) {
 		if (aia_nid[i] == nid) {
 			aiaOid->setCurrentIndex(i);
 		}
 	}
-	authInfAcc->setText(aia[1]);
+	authInfAcc->setText(aia_txt.mid(idx +1));
 }
 
 x509v3ext NewX509::getAuthInfAcc()
@@ -193,39 +198,27 @@ extList NewX509::getAdvanced()
 	extList elist;
 	long err_line=0;
 	STACK_OF(X509_EXTENSION) **sk, *sk_tmp = NULL;
-	char ext_name[] = "ext";
-	int ret, i, start;
+	const char *ext_name = "default";
+	int ret, start;
 
 	if (nconf_data->isReadOnly()) {
-		on_adv_validate_clicked();
+		conf_str = v3ext_backup;
+	} else {
+		conf_str = nconf_data->toPlainText();
 	}
-	conf_str = nconf_data->toPlainText();
 	if (conf_str.isEmpty())
 		return elist;
-	conf_str += "\n";
-	QStringList list = conf_str.split("\n", QString::SkipEmptyParts);
 
-	conf_str = QString("[") + ext_name + "]\n";
-	for (i=0; i< list.count(); i++) {
-		QString s = list[i].trimmed();
-		if (!s.isEmpty()){
-			conf_str += s + "\n";
-		}
-	}
-	bio = BIO_new_mem_buf((void*)CCHAR(conf_str), conf_str.length());
+	QByteArray cs = conf_str.toAscii();
+	bio = BIO_new_mem_buf(cs.data(), cs.length());
 	if (!bio)
 		return elist;
 	conf = NCONF_new(NULL);
 	ret = NCONF_load_bio(conf, bio, &err_line);
 	if (ret != 1) {
-		int i = ERR_get_error();
-		printf("Ret: %d, ERRLINE=%ld: %s\n", ret, err_line,
-			ERR_error_string(i ,NULL));
-
-		QMessageBox::warning(this, XCA_TITLE,
-			tr("Advanced Settings Error: ") +
-			ERR_error_string(i ,NULL), tr("OK"));
 		BIO_free(bio);
+		openssl_error(tr("Configfile error on line %1\n").
+				arg(err_line));
 		return elist;
 	}
 
@@ -238,13 +231,17 @@ extList NewX509::getAdvanced()
 	}
 
 	X509V3_set_nconf(&ext_ctx, conf);
-	X509V3_EXT_add_nconf_sk(conf, &ext_ctx, ext_name, sk);
+
+	if (X509V3_EXT_add_nconf_sk(conf, &ext_ctx, (char *)ext_name, sk)) {
+		openssl_error();
+	}
 	elist.setStack(*sk, start);
 	if (sk == &sk_tmp)
 		sk_X509_EXTENSION_pop_free(sk_tmp, X509_EXTENSION_free);
 	X509V3_set_nconf(&ext_ctx, NULL);
 	NCONF_free(conf);
 	BIO_free(bio);
+	openssl_error();
 	return elist;
 }
 
@@ -261,6 +258,7 @@ extList NewX509::getGuiExt()
 	ne << getIssAltName();
 	ne << getCrlDist();
 	ne << getAuthInfAcc();
+	openssl_error();
 	return ne;
 }
 
@@ -314,7 +312,7 @@ void NewX509::initCtx(pki_x509 *subj, pki_x509 *iss, pki_x509req *req)
 	X509V3_set_ctx(&ext_ctx, s, s1, r, NULL, 0);
 }
 
-int NewX509::checkExtDuplicates()
+extList NewX509::getExtDuplicates()
 {
 	int i, start, cnt, n1, n;
 	x509v3ext e;
@@ -325,7 +323,7 @@ int NewX509::checkExtDuplicates()
 	if (ext_ctx.subject_cert) {
 		sk = ext_ctx.subject_cert->cert_info->extensions;
 	} else
-		return 0;
+		return el_dup;
 
 	el.setStack(sk, 0);
 	if (fromReqCB->isChecked() && copyReqExtCB->isChecked()) {
@@ -346,23 +344,7 @@ int NewX509::checkExtDuplicates()
 			}
 		}
         }
-	if (el_dup.size() <= 0)
-		return 0;
-
-	tabWidget->setCurrentIndex(tabWidget->count() -1);
-	if (!nconf_data->isReadOnly()) {
-		on_adv_validate_clicked();
-	}
-
-	olist = "<h2><center><font color=\"red\">Error:</font> "
-		"duplicate extensions:</center></h2><p><ul>\n";
-	for(int i = 0; i< el_dup.size(); i++) {
-		olist += "<li>" + el_dup[i].getObject() + "</li>\n";
-	}
-	olist += "</ul>\n<hr>\n";
-	olist += valid_htmltext;
-	nconf_data->document()->setHtml(olist);
-	return el_dup.size();
+	return el_dup;
 }
 
 void NewX509::setExt(const x509v3ext &ext)
