@@ -5,15 +5,31 @@
  * All rights reserved.
  */
 
-#ifndef _XCATREEVIEW_H
-#define _XCATREEVIEW_H
+#ifndef __XCATREEVIEW_H
+#define __XCATREEVIEW_H
 
-#include <qtreeview.h>
-#include <qitemselectionmodel.h>
-#include <qsortfilterproxymodel.h>
+#include <QtGui/QTreeView>
+#include <QtGui/QItemSelectionModel>
+#include <QtGui/QSortFilterProxyModel>
+#include <QtGui/QHeaderView>
 #include "lib/db_base.h"
 
 class db_base;
+
+class XcaHeaderView: public QHeaderView
+{
+	Q_OBJECT
+    public:
+	XcaHeaderView()
+		:QHeaderView(Qt::Horizontal)
+	{
+		setMovable(true);
+	}
+	void contextMenuEvent(QContextMenuEvent *e);
+    public slots:
+	void resetMoves();
+};
+
 class XcaTreeView: public QTreeView
 {
 	Q_OBJECT
@@ -23,19 +39,18 @@ class XcaTreeView: public QTreeView
    public:
 	XcaTreeView(QWidget *parent = 0);
 	~XcaTreeView();
-	void contextMenuEvent(QContextMenuEvent * e);
+	void contextMenuEvent(QContextMenuEvent *e);
 	void setModel(QAbstractItemModel *model);
 	QModelIndex getIndex(const QModelIndex &index);
 	QModelIndex getProxyIndex(const QModelIndex &index);
 	QModelIndexList getSelectedIndexes();
+	void headerEvent(QContextMenuEvent *e, int col);
+
+   public slots:
+	void showHideSections();
+	void sectionMoved(int idx, int oldI, int newI);
 	void columnsResize();
-
-};
-
-class CertTreeView: public XcaTreeView
-{
-   public:
-	CertTreeView(QWidget *parent = 0);
+	void editIdx(const QModelIndex &idx);
 };
 
 class XcaProxyModel: public QSortFilterProxyModel
@@ -46,5 +61,4 @@ class XcaProxyModel: public QSortFilterProxyModel
 	bool lessThan(const QModelIndex &left, const QModelIndex &right) const;
 };
 
-
 #endif
