@@ -5,11 +5,11 @@
  * All rights reserved.
  */
 
-#ifndef DISTNAME_H
-#define DISTNAME_H
+#ifndef __DISTNAME_H
+#define __DISTNAME_H
 
-#include <qwidget.h>
-#include <qgridlayout.h>
+#include <QtGui/QWidget>
+#include <QtGui/QGridLayout>
 
 class x509name;
 class QLabel;
@@ -22,14 +22,12 @@ class DistName : public QWidget
     Q_OBJECT
 
   public:
-	DistName(QWidget* parent);
-	~DistName();
+	DistName(QWidget *parent);
 	void setX509name(const x509name &n);
 
   protected:
 	QGridLayout* DistNameLayout;
-	QLineEdit *lineEdit;
-	void resizeEvent( QResizeEvent *e);
-
+	QLineEdit *rfc2253;
+	QLineEdit *namehash;
 };
 #endif
